# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 11:21
from __future__ import unicode_literals

import codenerix_pos.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0026_pos_commit'),
    ]

    operations = [
        migrations.AddField(
            model_name='poshardware',
            name='profile',
            field=models.CharField(blank=True, max_length=30, verbose_name='Profile'),
        ),
        migrations.AlterField(
            model_name='pos',
            name='key',
            field=models.CharField(default=codenerix_pos.models.keymaker, editable=False, max_length=32, unique=True, verbose_name='Key'),
        ),
        migrations.AlterField(
            model_name='poshardware',
            name='key',
            field=models.CharField(default=codenerix_pos.models.keymaker, editable=False, max_length=32, unique=True, verbose_name='Key'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-21 15:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_pos', '0027_auto_20170921_1321'),
    ]

    operations = [
        migrations.AlterField(
            model_name='poshardware',
            name='profile',
            field=models.CharField(blank=True, default='CONFIG', max_length=30, verbose_name='Profile'),
        ),
    ]
